Microfrontend class abstract

Implementers

Constructors

Microfrontend()

Properties

component → String
no setter
divider → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
prefix → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persistValue(String key, String value) → String
projectNameComplete(String projectName) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited